/*
 *  FILE    : ConfigPanel.java
 *  Ver     : 1.0      (Dec., `99)
 *  AUHTHOR : Sangyoon Oh
 *            soh@napc.syr.edu
 *
 */


import java.awt.*;
import java.awt.event.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;

public class ConfigPanel extends JPanel {

    //ctor
    public ConfigPanel(MainPanel _mp) {
        
        mp = _mp;
        
        // default button
        defaultButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                setDefault();                    
            }
        });
        
        // set button
        setButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                
                // get parameters from Data module
                communityName = mp.parent.comMaster;
                communityAddress = mp.parent.dm.getValue("community", mp.parent.comMaster, "e-mail");
                adminEmail = mp.parent.dm.getValue("user", mp.parent._userName, "e-mail");
                   
                // get configuration parameters from panel
                String policy = (String) subscribe_policy.getSelectedItem();
                String isModerate;
                if(moderate.isSelected()) isModerate = "yes";
                else isModerate = "No";
                String pInfo;
                if(private_info.isSelected()) pInfo = "yes";
                else pInfo = "No";
                String pWhich;
                if(private_which.isSelected()) pWhich = "yes";  
                else pWhich = "No";
                String pWho;
                if(private_who.isSelected()) pWho = "yes";
                else pWho = "No";
                
                // set new password
                pDialog = new PasswdDialog(mp.parent);
                pDialog.setVisible(true);
                if(pDialog.getValid()) {
                    String passWd = pDialog.getPasswd();
                    pDialog.dispose();
                    setUpMail();            
                    try {
                        tm.setContext("newconfig " + mp.parent.comMaster + " " + passWd + "\n" +
                                      "subscribe_policy = " + policy + "\n" +
                                      "moderate = " + isModerate + "\n" +
                                      "private_info = " + pInfo + "\n" +
                                      "private_which = " + pWhich + "\n" +
                                      "private_who = " + pWho + "\n" +
                                      "EOF");
                        tm.sendMail();
                        JOptionPane.showMessageDialog( mp.parent.frame, "Configuration is changed!", "Configuration", JOptionPane.INFORMATION_MESSAGE );    
                        setDefault();
                    }
                    catch(MailException me) {}
                }
            }
        });        

        // subscribe_policy
        subscribe_policy.addItem("Auto");
        subscribe_policy.addItem("Open");
        subscribe_policy.addItem("Closed");
        subscribe_policy.setSelectedItem("Open");
        
        // option panel
	gbConstraints.fill = GridBagConstraints.NONE;
	gbConstraints.anchor = GridBagConstraints.WEST;         
        JPanel optionPanel = new JPanel(gbLayout);
        optionPanel.setBorder(new CompoundBorder(
            new EmptyBorder(5, 5, 0, 5), new EtchedBorder()));
    	addComponent(optionPanel, new JLabel("Subscribe Policy:"), 0, 0, 1, 1, new Insets(5, 5, 2, 2));
    	addComponent(optionPanel, new JLabel("Moderate:"), 1, 0, 1, 1, new Insets(0, 5, 2, 2));
        addComponent(optionPanel, new JLabel("Private Info:"), 2, 0, 1, 1, new Insets(0, 5, 2, 2));
        addComponent(optionPanel, new JLabel("Private Which:"), 3, 0, 1, 1, new Insets(0, 5, 2, 2));
        addComponent(optionPanel, new JLabel("Private Who:"), 4, 0, 1, 1, new Insets(0, 5, 2, 2));        
    	gbConstraints.anchor = GridBagConstraints.EAST;          
        // second colum
    	addComponent(optionPanel, subscribe_policy, 0, 1, 1, 1, new Insets(5, 43, 2, 12));
    	addComponent(optionPanel, moderate, 1, 1, 1, 1, new Insets(0, 50, 2, 5));
        addComponent(optionPanel, private_info, 2, 1, 1, 1, new Insets(0, 50, 2, 5));    	                  
        addComponent(optionPanel, private_which, 3, 1, 1, 1, new Insets(0, 50, 2, 5));    	                  
        addComponent(optionPanel, private_who, 4, 1, 1, 1, new Insets(0, 50, 2, 5));    	                  
        
        // button panel
        JPanel buttonPanel = new JPanel(new FlowLayout(FlowLayout.RIGHT));
        buttonPanel.add(defaultButton);
        buttonPanel.add(setButton);
        
        // gui
        setLayout(new BorderLayout());
        add(optionPanel, BorderLayout.CENTER);
        add(buttonPanel, BorderLayout.SOUTH);
    }
    
    // addComponent:
    // adds components to container according to grid
    // constraints parameters
    public void addComponent(JPanel p, JComponent c, int row, int column,
     	                     int width, int height, Insets insets) {
	     // set gridx and gridy
	     gbConstraints.gridx = column;
         gbConstraints.gridy = row;
         // set gridwidth and gridheight
	     gbConstraints.gridwidth = width;
         gbConstraints.gridheight = height;
         gbConstraints.insets = insets; 
	     // set constraints
	     gbLayout.setConstraints(c, gbConstraints);         
	     // add component
         p.add(c);
	}
	
	// set up mail parameters
	public void setUpMail() {
        try {
            StringTokenizer st = new StringTokenizer(communityAddress, "@");
            st.nextToken();
            tm = new TangoMail(st.nextToken());
            System.out.println("TM established");
            tm.setSubject("");
            tm.setFrom("", adminEmail);
            v.removeAllElements();
            h.put("toname", communityName);
            h.put("toadr", communityAddress);
            v.addElement(h);
            tm.addTo(v);
        }
        catch(Exception e1) {}
    }
    
    // set panel as default
    public void setDefault() {  
        subscribe_policy.setSelectedItem("Open");
        moderate.setSelected(false);  
        private_info.setSelected(false);  
        private_which.setSelected(false);  
        private_who.setSelected(false);         
    }
    
    private GridBagConstraints gbConstraints = new GridBagConstraints();
    private GridBagLayout gbLayout = new GridBagLayout();   
    protected JComboBox subscribe_policy = new JComboBox();
    protected JCheckBox moderate = new JCheckBox();
    protected JCheckBox private_info = new JCheckBox();
    protected JCheckBox private_which = new JCheckBox();
    protected JCheckBox private_who = new JCheckBox();
    protected JButton defaultButton = new JButton("Default");
    protected JButton setButton = new JButton("Set");    

    protected Vector v = new Vector(); 
    protected Hashtable h = new Hashtable();
    protected String communityAddress;
    protected String communityName;
    protected String adminEmail;
    protected String passWd;
    protected boolean modal;
    
    protected MainPanel mp;
    protected TangoMail tm;        
    protected PasswdDialog pDialog;
}





